@@ -23,6 +23,11 @@
 ################################################################################
 */
 
+/*
+ * This product is covered by one or more of the following patents:
+ * US5,307,459, US5,434,872, US5,732,094, US6,570,884, US6,115,776, and US6,327,625.
+ */
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 #define CHECKSUM_PARTIAL CHECKSUM_HW
 #endif
@@ -45,6 +50,10 @@
 #define SET_MODULE_OWNER(dev)
 #endif
 
+#ifndef SA_SHIRQ
+#define SA_SHIRQ IRQF_SHARED
+#endif
+
 //Due to the hardware design of RTL8101E, the low 32 bit address of receive
 //buffer must be 8-byte alignment.
 #undef NET_IP_ALIGN
@@ -52,15 +61,13 @@
 
 #define NODE_ADDRESS_SIZE 6
 
-#define CONFIG_R8101_NAPI 1
-
 #ifdef CONFIG_R8101_NAPI
 #define NAPI_SUFFIX	"-NAPI"
 #else
 #define NAPI_SUFFIX	""
 #endif
 
-#define RTL8101_VERSION "1.009.00" NAPI_SUFFIX
+#define RTL8101_VERSION "1.011.00" NAPI_SUFFIX
 #define MODULENAME "r8101"
 #define PFX MODULENAME ": "
 
@@ -335,6 +342,22 @@ static inline int _kc_pci_dma_mapping_error(dma_addr_t dma_addr)
  #define rtl_rmb()	rmb()
 #endif
 
+/* ----------------------------------------------------------- */
+
+
+enum RTL8101_VLAN_TYPE {
+	RTL_S_VLAN = 1,
+	RTL_H_VLAN = 2,
+};
+
+enum RTL8101_DSM_STATE {
+	DSM_MAC_INIT = 1,
+	DSM_NIC_GOTO_D3 = 2,
+	DSM_IF_DOWN = 3,
+	DSM_NIC_RESUME_D3 = 4,
+	DSM_IF_UP = 5,
+};
+
 enum RTL8101_registers {
 	MAC0 = 0,		/* Ethernet hardware address. */
 	MAC4 = 0x04,
@@ -364,6 +387,8 @@ enum RTL8101_registers {
 	CSIDR = 0x64,
 	CSIAR = 0x68,
 	PHYstatus = 0x6C,
+	MACDBG = 0x6D,
+	GPIO = 0x6E,
 	PMCH = 0x6F,
 	EPHYAR = 0x80,
 	DBG_reg = 0xD1,
@@ -520,6 +545,10 @@ enum RTL8101_register_content {
 	CSIAR_ByteEn = 0x0f,
 	CSIAR_ByteEn_shift = 12,
 	CSIAR_Addr_Mask = 0x0fff,
+
+	/* GPIO */
+	GPIO_en = (1 << 0),	
+
 };
 
 enum _DescStatusBit {
@@ -604,11 +633,6 @@ struct pci_resource {
 	u16	resv_0x24_l;
 };
 
-enum features {
-//	RTL_FEATURE_WOL	= (1 << 0),
-	RTL_FEATURE_MSI	= (1 << 1),
-};
-
 struct rtl8101_private {
 	void __iomem *mmio_addr;	/* memory map physical address */
 	struct pci_dev *pci_dev;	/* Index of PCI device */
@@ -652,6 +676,7 @@ struct rtl8101_private {
 #ifdef CONFIG_R8101_VLAN
 	struct vlan_group *vlgrp;
 #endif
+	int vlan_type;
 	int (*set_speed)(struct net_device *, u8 autoneg, u16 speed, u8 duplex);
 	void (*get_settings)(struct net_device *, struct ethtool_cmd *);
 	void (*phy_reset_enable)(struct net_device *);
